yt.analysis_modules.star_analysis.sfr_spectrum.SpectrumBuilder — The yt Project 3.2-dev documentation

# yt.analysis_modules.star_analysis.sfr_spectrum.SpectrumBuilder

class `yt.analysis_modules.star_analysis.sfr_spectrum.` `SpectrumBuilder`(ds, bcdir='', model='chabrier', time_now=None, star_filter=None)

  Initialize the data to build a summed flux spectrum for a collection of stars using the models of Bruzual & Charlot (2003). This function loads the necessary data tables into memory and must be called before analyzing any star particles.

  Parameters: | ds : EnzoDataset object bcdir : String Path to directory containing Bruzual & Charlot h5 fit files. model : String Choice of Initial Metalicity Function model, ‘chabrier’ or ‘salpeter’. Default = ‘chabrier’.

  Examples

      >>> import yt
      >>> from yt.analysis_modules.star_analysis.api import SpectrumBuilder
      >>> ds = yt.load("Enzo_64/RD0006/RedshiftOutput0006")
      >>> spec = SpectrumBuilder(ds, "bc", model="salpeter")

  Methods